@@ -2,7 +2,8 @@
 
 ##  extending_autograd.py
 
-"""This script is for experimenting with extending Autograd and it calls on
+"""
+This script is for experimenting with extending Autograd and it calls on
 DLStudio's inner class AutogradCustomization for the demonstration.
 
 The purpose of this inner class is to illustrate how to extend Autograd with
